// backend/routes/conversationRoutes.js
const express = require('express');
const router = express.Router();
const { 
    createOrGetConversation,
    getUserConversations, 
    getMessagesForConversation,
    deleteMessage // Импортируем новый контроллер
} = require('../controllers/conversationController');
const { protect } = require('../middleware/authMiddleware');

// Все маршруты здесь требуют аутентификации
router.use(protect);

router.route('/')
  .post(createOrGetConversation)   // POST /api/conversations (создать/найти диалог)
  .get(getUserConversations);     // GET /api/conversations (получить все диалоги пользователя)

router.route('/:conversationId/messages')
  .get(getMessagesForConversation); 

// Новый маршрут для удаления сообщения
router.route('/:conversationId/messages/:messageId')
  .delete(deleteMessage); // DELETE /api/conversations/:conversationId/messages/:messageId (удалить сообщение)

module.exports = router;